@@ -1,6 +1,7 @@
-from typing import Any, Callable, List, Optional, Dict
+from typing import Any, Callable, List, Optional, Dict, Union
 
-import numpy as np  # type: ignore
+import numpy as np
+import numpy.typing as npt
 from dataclasses import dataclass, field
 
 from code_loader.contract.enums import DataStateType, DatasetInputType, DatasetOutputType, DatasetMetadataType, \
@@ -14,6 +15,12 @@ class SubsetResponse:
 
 
 SectionCallableInterface = Callable[[int, SubsetResponse], np.ndarray]
+MetadataSectionCallableInterface = Union[
+    Callable[[int, SubsetResponse], int],
+    Callable[[int, SubsetResponse], str],
+    Callable[[int, SubsetResponse], bool],
+    Callable[[int, SubsetResponse], float]
+]
 
 
 @dataclass
@@ -45,7 +52,10 @@ class GroundTruthHandler(DatasetBaseHandler):
 
 
 @dataclass
-class MetadataHandler(DatasetBaseHandler):
+class MetadataHandler:
+    name: str
+    function: MetadataSectionCallableInterface
+    subset_name: str
     type: DatasetMetadataType
 
 
@@ -59,8 +69,8 @@ class DatasetIntegrationSetup:
 
 @dataclass
 class DatasetSample:
-    inputs: Dict[str, np.ndarray]
-    gt: Dict[str, np.ndarray]
-    metadata: Dict[str, np.ndarray]
+    inputs: Dict[str, npt.NDArray[np.float32]]
+    gt: Dict[str, npt.NDArray[np.float32]]
+    metadata: Dict[str, Union[str, int, bool, float]]
     index: int
     state: DataStateEnum
